package com.cultural.heritage.model.dto.coupon;

import com.cultural.heritage.common.PageRequest;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serial;
import java.io.Serializable;
import java.util.Date;


@Data
@EqualsAndHashCode(callSuper = true)
@Schema(description = "优惠券查询请求体", requiredProperties = {"current", "pageSize"})
public class CouponQueryRequest extends PageRequest implements Serializable {

    /**
     * 优惠券id
     */
    @Schema(description = "优惠券id(id > 0)", example = "4")
    private Long id;

    /**
     * 优惠券名称
     */
    @Schema(description = "优惠券名称", example = "满200减50")
    private String name;


    /**
     * 有效开始日期
     */
    @Schema(description = "有效开始日期", example = "2024-11-04 15:00:00")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date startTime;


    /**
     * 有效截止日期
     */
    @Schema(description = "有效截止日期", example = "2024-12-04 15:00:00")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date endTime;



    @Serial
    private static final long serialVersionUID = 1L;
}
